@@ -3,8 +3,6 @@ import argparse
 import functools
 import json
 import os
-import re
-import stat
 import sys
 from io import TextIOWrapper
 from pathlib import Path
@@ -15,14 +13,42 @@ from . import __version__, api, sections
 from .exceptions import FileSkipped
 from .logo import ASCII_ART
 from .profiles import profiles
-from .settings import SUPPORTED_EXTENSIONS, VALID_PY_TARGETS, Config, WrapModes
+from .settings import VALID_PY_TARGETS, Config, WrapModes
 
 try:
     from .setuptools_commands import ISortCommand  # noqa: F401
 except ImportError:
     pass
 
-shebang_re = re.compile(br"^#!.*\bpython[23w]?\b")
+DEPRECATED_SINGLE_DASH_ARGS = {
+    "-ac",
+    "-af",
+    "-ca",
+    "-cs",
+    "-df",
+    "-ds",
+    "-dt",
+    "-fas",
+    "-fass",
+    "-ff",
+    "-fgw",
+    "-fss",
+    "-lai",
+    "-lbt",
+    "-le",
+    "-ls",
+    "-nis",
+    "-nlb",
+    "-ot",
+    "-rr",
+    "-sd",
+    "-sg",
+    "-sl",
+    "-sp",
+    "-tc",
+    "-wl",
+    "-ws",
+}
 QUICK_GUIDE = f"""
 {ASCII_ART}
 
@@ -39,32 +65,6 @@ Visit https://timothycrosley.github.io/isort/ for complete information about how
 """
 
 
-def is_python_file(path: str) -> bool:
-    _root, ext = os.path.splitext(path)
-    if ext in SUPPORTED_EXTENSIONS:
-        return True
-    if ext in (".pex",):
-        return False
-
-    # Skip editor backup files.
-    if path.endswith("~"):
-        return False
-
-    try:
-        if stat.S_ISFIFO(os.stat(path).st_mode):
-            return False
-    except OSError:
-        pass
-
-    try:
-        with open(path, "rb") as fp:
-            line = fp.readline(100)
-    except OSError:
-        return False
-    else:
-        return bool(shebang_re.match(line))
-
-
 class SortAttempt:
     def __init__(self, incorrectly_sorted: bool, skipped: bool) -> None:
         self.incorrectly_sorted = incorrectly_sorted
@@ -128,7 +128,7 @@ def iter_source_code(paths: Iterable[str], config: Config, skipped: List[str]) -
 
                 for filename in filenames:
                     filepath = os.path.join(dirpath, filename)
-                    if is_python_file(filepath):
+                    if config.is_supported_filetype(filepath):
                         if config.is_skipped(Path(filepath)):
                             skipped.append(filename)
                         else:
@@ -635,11 +635,23 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--float-to-top",
         dest="float_to_top",
         action="store_true",
-        help="Causes all non indented imports to float to the top of the file having its imports "
-        "sorted. *NOTE*: This is an **experimental** feature. It currently doesn't work with "
-        "cimports and is guaranteed to run much slower and use much more memory than the default. "
-        "Still it can be a great shortcut for collecting imports every once in a while when you put"
-        " them in the middle of a file.",
+        help="Causes all non-indented imports to float to the top of the file having its imports "
+        "sorted.  It can be an excellent shortcut for collecting imports every once in a while "
+        "when you place them in the middle of a file to avoid context switching.\n\n"
+        "*NOTE*: It currently doesn't work with cimports and introduces some extra over-head "
+        "and a performance penalty.",
+    )
+    parser.add_argument(
+        "--treat-comment-as-code",
+        dest="treat_comments_as_code",
+        action="append",
+        help="Tells isort to treat the specified single line comment(s) as if they are code.",
+    )
+    parser.add_argument(
+        "--treat-all-comment-as-code",
+        dest="treat_all_comments_as_code",
+        action="store_true",
+        help="Tells isort to treat all single line comments as if they are code.",
     )
     parser.add_argument(
         "--formatter",
@@ -647,6 +659,27 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         type=str,
         help="Specifies the name of a formatting plugin to use when producing output.",
     )
+    parser.add_argument(
+        "--ext",
+        "--extension",
+        "--supported-extension",
+        dest="supported_extensions",
+        action="append",
+        help="Specifies what extensions isort can be ran against.",
+    )
+    parser.add_argument(
+        "--blocked-extension",
+        dest="blocked_extensions",
+        action="append",
+        help="Specifies what extensions isort can never be ran against.",
+    )
+    parser.add_argument(
+        "--dedup-headings",
+        dest="dedup_headings",
+        action="store_true",
+        help="Tells isort to only show an identical custom import heading comment once, even if"
+        " there are multiple sections with the comment set.",
+    )
 
     # deprecated options
     parser.add_argument(
@@ -684,10 +717,24 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         const="--keep-direct-and-as",
         help=argparse.SUPPRESS,
     )
+
     return parser
 
 
 def parse_args(argv: Optional[Sequence[str]] = None) -> Dict[str, Any]:
+    argv = sys.argv[1:] if argv is None else list(argv)
+    for index, arg in enumerate(argv):
+        if arg in DEPRECATED_SINGLE_DASH_ARGS:
+            warn(
+                f"\n\nThe following deprecated single dash CLI flags was used: {arg}!\n"
+                f"It is being auto translated to -{arg} to maintain backward compatibility.\n"
+                f"This behavior will be REMOVED in the 6.x.x release and is not guaranteed across"
+                f" 5.x.x releases.\n\n"
+                "Please see the 5.0.0 upgrade guide:\n"
+                "\thttps://timothycrosley.github.io/isort/docs/upgrade_guides/5.0.0/\n"
+            )
+            argv[index] = f"-{arg}"
+
     parser = _build_arg_parser()
     arguments = {key: value for key, value in vars(parser.parse_args(argv)).items() if value}
     if "dont_order_by_type" in arguments:
@@ -739,7 +786,10 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
     file_names = arguments.pop("files", [])
     if not file_names and not show_config:
         print(QUICK_GUIDE)
-        return
+        if arguments:
+            sys.exit("Error: arguments passed in without any paths or content.")
+        else:
+            return
     elif file_names == ["-"] and not show_config:
         arguments.setdefault("settings_path", os.getcwd())
         api.sort_stream(
