@@ -55,7 +55,7 @@ def import_type(line: str, config: Config = DEFAULT_CONFIG) -> Optional[str]:
     """If the current line is an import line it will return its type (from or straight)"""
     if config.honor_noqa and line.lower().rstrip().endswith("noqa"):
         return None
-    elif "isort:skip" in line or "isort: skip" in line:
+    elif "isort:skip" in line or "isort: skip" in line or "isort: split" in line:
         return None
     elif line.startswith(("import ", "cimport ")):
         return "straight"
@@ -80,7 +80,11 @@ def _strip_syntax(import_string: str) -> str:
 
 
 def skip_line(
-    line: str, in_quote: str, index: int, section_comments: Tuple[str, ...]
+    line: str,
+    in_quote: str,
+    index: int,
+    section_comments: Tuple[str, ...],
+    needs_import: bool = True,
 ) -> Tuple[bool, str]:
     """Determine if a given line should be skipped.
 
@@ -109,7 +113,7 @@ def skip_line(
                 break
             char_index += 1
 
-    if ";" in line:
+    if ";" in line and needs_import:
         for part in (part.strip() for part in line.split(";")):
             if (
                 part
@@ -127,7 +131,7 @@ class ParsedContent(NamedTuple):
     import_index: int
     place_imports: Dict[str, List[str]]
     import_placements: Dict[str, str]
-    as_map: Dict[str, List[str]]
+    as_map: Dict[str, Dict[str, List[str]]]
     imports: Dict[str, Dict[str, Any]]
     categorized_comments: "CommentsDict"
     change_count: int
@@ -139,7 +143,10 @@ class ParsedContent(NamedTuple):
 def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedContent:
     """Parses a python file taking out and categorizing imports."""
     line_separator: str = config.line_ending or _infer_line_separator(contents)
-    in_lines = contents.split(line_separator)
+    in_lines = contents.splitlines()
+    if contents and contents[-1] in ("\n", "\r"):
+        in_lines.append("")
+
     out_lines = []
     original_line_count = len(in_lines)
     if config.old_finders:
@@ -151,7 +158,10 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
 
     place_imports: Dict[str, List[str]] = {}
     import_placements: Dict[str, str] = {}
-    as_map: Dict[str, List[str]] = defaultdict(list)
+    as_map: Dict[str, Dict[str, List[str]]] = {
+        "straight": defaultdict(list),
+        "from": defaultdict(list),
+    }
     imports: OrderedDict[str, Dict[str, Any]] = OrderedDict()
     for section in chain(config.sections, config.forced_separate):
         imports[section] = {"straight": OrderedDict(), "from": OrderedDict()}
@@ -284,7 +294,11 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
 
             if type_of_import == "from":
                 cimports: bool
-                import_string = import_string.replace("import(", "import (")
+                import_string = (
+                    import_string.replace("import(", "import (")
+                    .replace("\\", " ")
+                    .replace("\n", " ")
+                )
                 if " cimport " in import_string:
                     parts = import_string.split(" cimport ")
                     cimports = True
@@ -308,19 +322,20 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                 while "as" in just_imports:
                     as_index = just_imports.index("as")
                     if type_of_import == "from":
-                        module = just_imports[0] + "." + just_imports[as_index - 1]
+                        nested_module = just_imports[as_index - 1]
+                        module = just_imports[0] + "." + nested_module
                         as_name = just_imports[as_index + 1]
-                        if as_name not in as_map[module]:
-                            as_map[module].append(as_name)
+                        if nested_module == as_name and config.remove_redundant_aliases:
+                            pass
+                        elif as_name not in as_map["from"][module]:
+                            as_map["from"][module].append(as_name)
                     else:
                         module = just_imports[as_index - 1]
                         as_name = just_imports[as_index + 1]
-                        if as_name not in as_map[module]:
-                            as_map[module].append(as_name)
-                        if "." in module:
-                            type_of_import = "from"
-                            just_imports[:as_index] = module.rsplit(".", 1)
-                            as_index = just_imports.index("as")
+                        if module == as_name and config.remove_redundant_aliases:
+                            pass
+                        elif as_name not in as_map["straight"][module]:
+                            as_map["straight"][module].append(as_name)
                     if not config.combine_as_imports:
                         categorized_comments["straight"][module] = comments
                         comments = []
@@ -355,11 +370,13 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                         and not last.endswith("'''")
                         and "isort:imports-" not in last
                         and "isort: imports-" not in last
+                        and not config.treat_all_comments_as_code
+                        and not last.strip() in config.treat_comments_as_code
                     ):
                         categorized_comments["above"]["from"].setdefault(import_from, []).insert(
                             0, out_lines.pop(-1)
                         )
-                        if len(out_lines) > max(import_index - 1, 1) - 1:
+                        if out_lines:
                             last = out_lines[-1].rstrip()
                         else:
                             last = ""
@@ -392,6 +409,8 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                             and not last.endswith("'''")
                             and "isort:imports-" not in last
                             and "isort: imports-" not in last
+                            and not config.treat_all_comments_as_code
+                            and not last.strip() in config.treat_comments_as_code
                         ):
                             categorized_comments["above"]["straight"].setdefault(module, []).insert(
                                 0, out_lines.pop(-1)
